<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_ec_mainProductWidgetContainer.php 2260 2009-08-27 05:59:32Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetDbPath() .	'/productDb.php');

class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContainer
{
	private $db;	// DB接続オブジェクト
	private $serialNo;			// シリアル番号
	private $productId;			// 商品ID
	private $langId;			// 言語
	private $unitTypeId;		// 選択単位
	private $currency;			// 通貨
	private $taxType;			// 税種別
	private $ecObj;			// 共通ECオブジェクト
	private $categoryListData;		// 商品カテゴリー
	private $categoryArray;			// カテゴリー設定値
	const MAX_HIER_LEVEL = 20;		// カテゴリー階層最大値
	const STANDARD_PRICE = 'selling';		// 通常価格
	const PRODUCT_IMAGE_MEDIUM = 'standard-product';		// 中サイズ商品画像ID
	const PRODUCT_IMAGE_SMALL = 'small-product';		// 小サイズ商品画像ID
	const PRODUCT_IMAGE_LARGE = 'large-product';		// 大サイズ商品画像ID
	const PRODUCT_STATUS_NEW = 'new';		// 商品ステータス新規
	const PRODUCT_STATUS_SUGGEST = 'suggest';		// 商品ステータスおすすめ
	const DEFAULT_TAX_TYPE = 'sales';			// デフォルト税種別
	const PRICE_OBJ_ID = "eclib";		// 価格計算オブジェクトID
	const CATEGORY_COUNT = 5;				// 商品カテゴリーの選択可能数
		
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DBオブジェクト作成
		$this->db = new productDb();
		
		// EC用共通オブジェクト取得
		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
		$this->ecObj->initByDefault();		// デフォルト値で初期化
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{
		return 'admin_product.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		// ユーザ情報、表示言語
		$userId		= $this->gEnv->getCurrentUserId();
		$defaultLang	= $this->gEnv->getDefaultLanguage();
		$defaultLangName = $this->gEnv->getDefaultLanguageNameByCurrentLanguage();// デフォルト言語の現在の表示名を取得
		
		// 画像情報を取得
		$defaultImageSWidth = 0;
		$defaultImageSHeight = 0;
		$ret = $this->db->getProductImageInfo(self::PRODUCT_IMAGE_SMALL, $row);
		if ($ret){
			$defaultImageSWidth = $row['is_width'];
			$defaultImageSHeight = $row['is_height'];
		}
		$defaultImageMWidth = 0;
		$defaultImageMHeight = 0;
		$ret = $this->db->getProductImageInfo(self::PRODUCT_IMAGE_MEDIUM, $row);
		if ($ret){
			$defaultImageMWidth = $row['is_width'];
			$defaultImageMHeight = $row['is_height'];
		}
		$defaultImageLWidth = 0;
		$defaultImageLHeight = 0;
		$ret = $this->db->getProductImageInfo(self::PRODUCT_IMAGE_LARGE, $row);
		if ($ret){
			$defaultImageLWidth = $row['is_width'];
			$defaultImageLHeight = $row['is_height'];
		}
		
		$act = $request->trimValueOf('act');
		$this->serialNo = $request->trimValueOf('serial');			// 選択項目のシリアル番号
		if (empty($this->serialNo)) $this->serialNo = 0;
		$this->productId = $request->trimValueOf('productid');	// 商品ID
		if (empty($this->productId)) $this->productId = 0;
		$this->currency = $request->trimValueOf('item_currency');		// 通貨
		if (empty($this->currency)) $this->currency	= $this->ecObj->getDefaultCurrency();		// 通貨
		
		// 編集中の項目
		$name	= $request->trimValueOf('item_name');		// 商品名
		$code	= $request->trimValueOf('item_code');		// 商品コード
		$index	= $request->trimValueOf('item_index');		// 表示順
		$visible = ($request->trimValueOf('item_visible') == 'on') ? 1 : 0;			// 表示するかどうか
		$this->unitTypeId = $request->trimValueOf('item_unit_type');		// 選択単位
		$unitQuantity = $request->trimValueOf('item_unit_quantity');		// 数量
		$stockCount	= $request->trimValueOf('item_stock_count');		// 表示在庫数
		if (empty($stockCount)) $stockCount = 0;
		$delivType = $request->trimValueOf('item_deliv_type');		// 配送タイプ
		$delivPrice = $request->trimValueOf('item_deliv_price');		// 配送単価
		if (empty($delivPrice)) $delivPrice = 0;
		$delivWeight = $request->trimValueOf('item_deliv_weight');		// 配送基準重量
		if (empty($delivWeight)) $delivWeight = 0;
		$description = $request->valueOf('item_description');			// 説明
		$description_short = $request->valueOf('item_desc_short');		// 簡易説明
		$keyword = $request->valueOf('item_keyword');					// 検索キーワード
		$url = $request->valueOf('item_url');							// 詳細情報URL
		$this->taxType = $request->valueOf('item_tax_type');					// 税種別
		$adminNote = $request->trimValueOf('item_admin_note');		// 管理者用備考
		$price = $request->trimValueOf('item_price');		// 価格
		
		// 画像のパスをマクロ表記パスに直す
		$imageUrl_s = $request->trimValueOf('imageurl_s');		// 小画像
		if (!empty($imageUrl_s)){
			if (strncmp($imageUrl_s, '/', 1) == 0){		// 相対パス表記のとき
				$imageUrl_s = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . $this->gEnv->getRelativePathToSystemRootUrl($this->gEnv->getDocumentRootUrl() . $imageUrl_s);
			}
		}
		$imageUrl_m = $request->trimValueOf('imageurl_m');		// 中画像
		if (!empty($imageUrl_m)){
			if (strncmp($imageUrl_m, '/', 1) == 0){		// 相対パス表記のとき
				$imageUrl_m = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . $this->gEnv->getRelativePathToSystemRootUrl($this->gEnv->getDocumentRootUrl() . $imageUrl_m);
			}
		}
		$imageUrl_l = $request->trimValueOf('imageurl_l');		// 大画像
		if (!empty($imageUrl_l)){
			if (strncmp($imageUrl_l, '/', 1) == 0){		// 相対パス表記のとき
				$imageUrl_l = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . $this->gEnv->getRelativePathToSystemRootUrl($this->gEnv->getDocumentRootUrl() . $imageUrl_l);
			}
		}
		$new = ($request->trimValueOf('item_new') == 'on') ? 1 : 0;		// 新規
		$suggest = ($request->trimValueOf('item_suggest') == 'on') ? 1 : 0;		// おすすめ
		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
		if (empty($this->langId)) $this->langId = $defaultLang;			// 言語が選択されていないときは、デフォルト言語を設定
		
		// カテゴリーを取得
		$this->categoryArray = array();
		for ($i = 0; $i < self::CATEGORY_COUNT; $i++){
			$itemName = 'item_category' . $i;
			$itemValue = $request->trimValueOf($itemName);
			if (!empty($itemValue)){		// 0以外の値を取得
				$this->categoryArray[] = $itemValue;
			}
		}
	
		$reloadData = false;		// データ再取得するかどうか
		$keepProductId = false;		// 商品IDを維持するかどうか
		if ($act == 'select'){		// 項目選択の場合
			$reloadData = true;		// データ再取得
		} else if ($act == 'selectlang'){		// 言語選択の場合
			// 登録済み商品を取得
			$ret = $this->db->getProductByProductId($this->productId, $this->langId, $row, $row2, $row3, $row4, $row5);
			if ($ret){
				// 取得値を設定
				$this->serialNo = $row['pt_serial'];		// シリアル番号
				$reloadData = true;		// データ再取得
			} else {	// 指定した言語のデータがないとき
				// デフォルト値を設定
				$this->serialNo = 0;
				$name = '';		// 名前
			}
		} else if ($act == 'selectproduct'){		// 商品選択の場合
			// 登録済み商品を取得
			$ret = $this->db->getProductByProductId($this->productId, $this->langId, $row, $row2, $row3, $row4, $row5);
			if ($ret){
				// 取得値を設定
				$this->serialNo = $row['pt_serial'];		// シリアル番号
				$reloadData = true;		// データ再取得
			} else {	// 指定した商品のデータがないとき
				$this->serialNo = 0;		// シリアル番号
				$reloadData = true;		// データ再取得
			}
		} else if ($act == 'add'){		// 項目追加の場合
			// 入力チェック
			$this->checkInput($name, '商品名');
			$this->checkInput($code, '商品コード');
			$this->checkNumeric($index, '表示順');
			$this->checkNumericF($unitQuantity, '数量');
			$this->checkNumeric($stockCount, '表示在庫数');
			$this->checkNumericF($price, '商品価格');
			if (empty($this->unitTypeId)) $this->setUserErrorMsg('販売単位が選択されていません');

			// エラーなしの場合は、データを登録
			if ($this->getMsgCount() == 0){
				// ##### 格納値を作成 #####
				// 商品情報その他
				$otherParams = array();
				$otherParams['pt_name'] = $name;			// 商品名
				$otherParams['pt_code'] = $code;			// 商品コード
				$otherParams['pt_sort_order'] = $index;			// 表示順
				$otherParams['pt_visible'] = $visible;		// 表示するかどうか
				$otherParams['pt_product_type'] = 1;				// 商品種別(1=単品商品、2=セット商品、3=オプション商品)
				$otherParams['pt_unit_type_id'] = $this->unitTypeId;	// 選択単位
				$otherParams['pt_unit_quantity'] = $unitQuantity;		// 数量
				$otherParams['pt_description'] = $description;		// 説明
				$otherParams['pt_description_short'] = $description_short;	// 簡易説明
				$otherParams['pt_search_keyword'] = $keyword;		// 検索キーワード
				$otherParams['pt_site_url'] = $url;			// 詳細情報URL
				$otherParams['pt_tax_type_id'] = $this->taxType;	// 税種別
				$otherParams['pt_admin_note'] = $adminNote;		// 管理者用備考
				$otherParams['pt_deliv_type'] = $delivType;		// 配送タイプ
				$otherParams['pt_deliv_fee'] = $delivPrice;		// 配送単価
				$otherParams['pt_weight'] = $delivWeight;		// 配送基準重量
				
				// 価格情報の作成
				$priceArray = array();
				$startDt = $this->gEnv->getInitValueOfTimestamp();
				$endDt = $this->gEnv->getInitValueOfTimestamp();
				$priceArray[] = array(self::STANDARD_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
				
				// 画像情報の作成
				$imageArray = array();
				if (!empty($imageUrl_s)) $imageArray[] = array(self::PRODUCT_IMAGE_SMALL, '', $imageUrl_s);		// 商品画像小追加
				if (!empty($imageUrl_m)) $imageArray[] = array(self::PRODUCT_IMAGE_MEDIUM, '', $imageUrl_m);		// 商品画像中追加
				if (!empty($imageUrl_l)) $imageArray[] = array(self::PRODUCT_IMAGE_LARGE, '', $imageUrl_l);		// 商品画像大追加
								
				// 商品ステータス情報の作成
				$statusArray = array();
				$statusArray[] = array(self::PRODUCT_STATUS_NEW, $new);		// 新着
				$statusArray[] = array(self::PRODUCT_STATUS_SUGGEST, $suggest);		// おすすめ
				if ($this->serialNo == 0 && $this->productId == 0){		// シリアル番号が0、商品IDが0のときは、新規商品追加モードにする
					$ret = $this->db->updateProduct(0/*データ新規追加*/, 0/*商品ID新規作成*/, $this->langId, $otherParams, 
													$stockCount, $priceArray, $imageArray, $statusArray, $this->categoryArray, $newSerial);
				} else {
					$ret = $this->db->updateProduct(0/*データ新規追加*/, $this->productId, $this->langId, $otherParams, 
													$stockCount, $priceArray, $imageArray, $statusArray, $this->categoryArray, $newSerial);
				}
				if ($ret){
					$this->setGuidanceMsg('データを追加しました');
					
					// シリアル番号更新
					$this->serialNo = $newSerial;
					$reloadData = true;		// データ再取得
				} else {
					$this->setAppErrorMsg('データ追加に失敗しました');
				}
			}
		} else if ($act == 'update'){		// 項目更新の場合
			// 入力チェック
			$this->checkInput($name, '商品名');
			$this->checkInput($code, '商品コード');
			$this->checkNumeric($index, '表示順');
			$this->checkNumericF($unitQuantity, '数量');
			$this->checkNumeric($stockCount, '表示在庫数');
			$this->checkNumericF($price, '商品価格');
			if (empty($this->unitTypeId)) $this->setUserErrorMsg('販売単位が選択されていません');
			
			// エラーなしの場合は、データを登録
			if ($this->getMsgCount() == 0 && !empty($this->serialNo)){
				// ##### 格納値を作成 #####
				// 商品情報その他
				$otherParams = array();
				$otherParams['pt_name'] = $name;			// 商品名
				$otherParams['pt_code'] = $code;			// 商品コード
				$otherParams['pt_sort_order'] = $index;			// 表示順
				$otherParams['pt_visible'] = $visible;		// 表示するかどうか
				$otherParams['pt_product_type'] = 1;				// 商品種別(1=単品商品、2=セット商品、3=オプション商品)
				$otherParams['pt_unit_type_id'] = $this->unitTypeId;	// 選択単位
				$otherParams['pt_unit_quantity'] = $unitQuantity;		// 数量
				$otherParams['pt_description'] = $description;		// 説明
				$otherParams['pt_description_short'] = $description_short;	// 簡易説明
				$otherParams['pt_search_keyword'] = $keyword;		// 検索キーワード
				$otherParams['pt_site_url'] = $url;			// 詳細情報URL
				$otherParams['pt_tax_type_id'] = $this->taxType;	// 税種別
				$otherParams['pt_admin_note'] = $adminNote;		// 管理者用備考
				$otherParams['pt_deliv_type'] = $delivType;		// 配送タイプ
				$otherParams['pt_deliv_fee'] = $delivPrice;		// 配送単価
				$otherParams['pt_weight'] = $delivWeight;		// 配送基準重量
		
				// 価格情報の作成
				$priceArray = array();
				$startDt = $this->gEnv->getInitValueOfTimestamp();
				$endDt = $this->gEnv->getInitValueOfTimestamp();
				$priceArray[] = array(self::STANDARD_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
				
				// 画像情報の作成
				$imageArray = array();
				if (!empty($imageUrl_s)) $imageArray[] = array(self::PRODUCT_IMAGE_SMALL, '', $imageUrl_s);		// 商品画像小追加
				if (!empty($imageUrl_m)) $imageArray[] = array(self::PRODUCT_IMAGE_MEDIUM, '', $imageUrl_m);		// 商品画像中追加
				if (!empty($imageUrl_l)) $imageArray[] = array(self::PRODUCT_IMAGE_LARGE, '', $imageUrl_l);		// 商品画像大追加
				
				// 商品ステータス情報の作成
				$statusArray = array();
				$statusArray[] = array(self::PRODUCT_STATUS_NEW, $new);		// 新着
				$statusArray[] = array(self::PRODUCT_STATUS_SUGGEST, $suggest);		// おすすめ
				
				$ret = $this->db->updateProduct($this->serialNo, $this->productId, $this->langId, $otherParams, 
												$stockCount, $priceArray, $imageArray, $statusArray, $this->categoryArray, $newSerial);
				if ($ret){
					$this->setGuidanceMsg('データを更新しました');
					
					$this->serialNo = $newSerial;
					$reloadData = true;		// データ再取得
				} else {
					$this->setAppErrorMsg('データ更新に失敗しました');
				}
			}
		} else if ($act == 'delete'){		// 項目削除の場合
			if (empty($this->serialNo)){
				$this->setUserErrorMsg('削除項目が選択されていません');
			}
			// エラーなしの場合は、データを削除
			if ($this->getMsgCount() == 0){
				$ret = $this->db->delProduct($this->serialNo);
				if ($ret){		// データ削除成功のとき
					$this->setGuidanceMsg('データを削除しました');
				} else {
					$this->setAppErrorMsg('データ削除に失敗しました');
				}
			}
		} else if ($act == 'deleteid'){		// ID項目削除の場合
			if (empty($this->serialNo)){
				$this->setUserErrorMsg('削除項目が選択されていません');
			}
			// エラーなしの場合は、データを削除
			if ($this->getMsgCount() == 0){
				$ret = $this->db->delProductById($this->serialNo);
				if ($ret){		// データ削除成功のとき
					$this->setGuidanceMsg('データを削除しました');
				} else {
					$this->setAppErrorMsg('データ削除に失敗しました');
				}
			}
		} else {	// 初期表示
			// 商品IDが指定されている場合は商品データ取得
			$productId = $request->trimValueOf('product');	// 商品ID
			if (empty($productId)){
				$this->serialNo = 0;		// シリアル番号
				$reloadData = true;		// データ再取得
			} else {
				$ret = $this->db->getProductByProductId($productId, $this->langId, $row, $row2, $row3, $row4, $row5);
				if ($ret){
					// 取得値を設定
					$this->serialNo = $row['pt_serial'];		// シリアル番号
					$reloadData = true;		// データ再取得
				} else {		// 指定した商品のデータがないとき
					$this->serialNo = 0;		// シリアル番号
					$reloadData = true;		// データ再取得
				}
			}
		}
		if ($reloadData){		// データ再取得のとき
			if (empty($this->serialNo)){
				// 入力値初期化
				$this->serialNo = 0;		// シリアル番号
				if (!$keepProductId) $this->productId = 0;	// 商品IDを維持しない場合は商品IDを初期化
				$this->langId = $defaultLang;
				$name = '';		// 名前
				$code = '';		// 商品コード
				$index = '';	// 表示順
				$visible = 1;	// 表示状態
				$new = 0;// 新規
				$suggest = 0;// おすすめ
				$price = '';	// 価格
				$this->currency	= $this->ecObj->getDefaultCurrency();		// 通貨
				$this->unitTypeId = '';	// 単位
				$unitQuantity = 1;		// 数量
				$stockCount	= 0;		// 表示在庫数
				$delivType = '';		// 配送タイプ
				$delivPrice = 0;		// 配送単価
				$delivWeight = 0;		// 配送基準重量
				$description = '';			// 説明
				$description_short = '';		// 簡易説明
				$keyword = '';					// 検索キーワード
				$url = '';							// 詳細情報URL
				$this->taxType	= self::DEFAULT_TAX_TYPE;		// 税種別
				$adminNote = '';		// 管理者用備考
				$updateUser = '';	// 更新者
				$updateDt = '';	// 更新日時	
				$imageUrl_s = '';		// 商品画像小
				$imageUrl_m = '';		// 商品画像中
				$imageUrl_l = '';		// 商品画像大
				$this->categoryArray = array();		// 商品カテゴリー			
			} else {
				// データ再取得
				$ret = $this->db->getProductBySerial($this->serialNo, $row, $row2, $row3, $row4, $row5);
				if ($ret){
					// 取得値を設定
					$this->productId = $row['pt_id'];	// 商品ID
					$this->langId = $row['pt_language_id'];
					$name = $row['pt_name'];		// 名前
					$code = $row['pt_code'];		// 商品コード
					$index = $row['pt_sort_order'];	// 表示順
					$visible = $row['pt_visible'];	// 表示状態
					$this->unitTypeId = $row['pt_unit_type_id'];	// 単位
					$unitQuantity = $row['pt_unit_quantity'];		// 数量
					$stockCount	= $row['pe_stock_count'];		// 表示在庫数
					if (empty($stockCount)) $stockCount = 0;
					$delivType = $row['pt_deliv_type'];		// 配送タイプ
					$delivPrice = $row['pt_deliv_fee'];		// 配送単価
					$delivWeight = $row['pt_weight'];		// 配送基準重量
					$description = $row['pt_description'];			// 説明
					$description_short = $row['pt_description_short'];		// 簡易説明
					$keyword = $row['pt_search_keyword'];					// 検索キーワード
					$url = $row['pt_site_url'];							// 詳細情報URL
					$this->taxType = $row['pt_tax_type_id'];					// 税種別
					$adminNote = $row['pt_admin_note'];		// 管理者用備考
					$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
					$updateDt = $this->convertToDispDateTime($row['pt_create_dt']);	// 更新日時
				
					// 価格を取得
					$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
					$price = $priceArray['pp_price'];	// 価格
					$this->currency = $priceArray['pp_currency_id'];	// 通貨
				
					// 画像を取得
					$imageArray = $this->getImage($row3, self::PRODUCT_IMAGE_SMALL);// 商品画像小
					$imageUrl_s = $imageArray['im_url'];	// URL
					$imageArray = $this->getImage($row3, self::PRODUCT_IMAGE_MEDIUM);// 商品画像中
					$imageUrl_m = $imageArray['im_url'];	// URL
					$imageArray = $this->getImage($row3, self::PRODUCT_IMAGE_LARGE);// 商品画像大
					$imageUrl_l = $imageArray['im_url'];	// URL
									
					// 商品ステータスを取得
					$statusArray = $this->getStatus($row4, self::PRODUCT_STATUS_NEW);// 新規
					$new = $statusArray['ps_value'];
					$statusArray = $this->getStatus($row4, self::PRODUCT_STATUS_SUGGEST);// おすすめ
					$suggest = $statusArray['ps_value'];
				
					// 商品カテゴリー取得
					$this->categoryArray = $this->getCategory($row5);
				}
			}
		}
		// 商品コードメニューを作成
		$this->db->getAllProductByLang($defaultLang, array($this, 'productListLoop'));// 商品リスト取得
				
		// カテゴリーメニューを作成
		$this->db->getAllCategory($defaultLang, $this->categoryListData);
		$this->createCategoryMenu();
		
		// #### 更新、新規登録部をを作成 ####
		// パラメータパターン
		// シリアル番号(0=未登録データ、0以外=登録済みデータ)
		// カテゴリーID(0=カテゴリー未選択、0以外=カテゴリー選択)
		// 商品ID(0=商品未選択、0以外=商品選択)
		
		// 選択中のカテゴリーIDを設定
		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
		if ($this->serialNo == 0 && $this->productId == 0){		// シリアル番号、商品IDが0のときは新規とする
		//if ($this->serialNo == 0){		// シリアル番号が0のときは新規とする
			/*if ($this->categoryId == 0){	// カテゴリーが選択されていないときはメッセージ
				$this->tmpl->addVar("_widget", "id", '商品カテゴリーが選択されていません');
				$this->tmpl->addVar("_widget", "name_disabled", 'disabled');		// 商品名入力不可
				$this->tmpl->addVar("_widget", "code_disabled", 'disabled');		// 商品コード入力不可
			} else {*/
				//$this->tmpl->addVar("_widget", "id", '新規');
			//}
			$this->tmpl->addVar("_widget", "new_selected", 'checked');// 新規追加をチェック状態にする
		
			// デフォルト言語を最初に登録
			if ($this->gEnv->getMultiLanguage()){	// 多言語対応のとき
				$this->tmpl->addVar("default_lang", "default_lang", $defaultLangName);
				$this->tmpl->setAttribute('default_lang', 'visibility', 'visible');
			}
		} else {
			$this->tmpl->addVar("_widget", "id", $this->productId);
		
			// 言語選択メニューを作成
			if ($this->gEnv->getMultiLanguage()){	// 多言語対応のとき
				$this->db->getAllLang(array($this, 'langLoop'));
				$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
			}
		}
		// 各種価格を求める
		$price = $this->ecObj->getCurrencyPrice($price);	// 端数調整
		$this->ecObj->setCurrencyType($this->currency, $this->langId);		// 通貨設定
		$this->ecObj->setTaxType($this->taxType, $this->langId);		// 税種別設定
		$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
		$delivPrice = $this->ecObj->getCurrencyPrice($delivPrice);	// 端数調整
		
		$this->tmpl->addVar("_widget", "name", $name);		// 名前
		$this->tmpl->addVar("_widget", "code", $code);		// 商品コード
		$this->tmpl->addVar("_widget", "index", $index);		// 表示順
		$this->tmpl->addVar("_widget", "unit_quantity", $unitQuantity);		// 数量
		$this->tmpl->addVar("_widget", "stock_count", $stockCount);		// 表示在庫数
		$this->tmpl->addVar("_widget", "deliv_type", $delivType);		// 配送タイプ
		$this->tmpl->addVar("_widget", "deliv_price", $delivPrice);		// 配送単価
		$this->tmpl->addVar("_widget", "deliv_weight", $delivWeight);		// 配送基準重量
		$this->tmpl->addVar("_widget", "description", $description);		// 説明
		$this->tmpl->addVar("_widget", "desc_short", $description_short);		// 簡易説明		
		$this->tmpl->addVar("_widget", "keyword", $keyword);		// 検索キーワード
		$this->tmpl->addVar("_widget", "url", $url);				// 詳細情報URL
		$this->tmpl->addVar("_widget", "admin_note", $adminNote);			// 管理者用備考
		$this->tmpl->addVar("_widget", "price", $price);		// 価格
		$this->tmpl->addVar("_widget", "price_with_tax", $dispPrice);		// 税込価格
		
		$visibleStr = '';
		if ($visible){	// 項目の表示
			$visibleStr = 'checked';
		}
		$this->tmpl->addVar("_widget", "visible", $visibleStr);		// 表示状態
		$visibleStr = '';
		if ($new){	// 新規
			$visibleStr = 'checked';
		}
		$this->tmpl->addVar("_widget", "new", $visibleStr);
		$visibleStr = '';
		if ($suggest){	// おすすめ
			$visibleStr = 'checked';
		}
		$this->tmpl->addVar("_widget", "suggest", $visibleStr);
		if (!empty($updateUser)) $this->tmpl->addVar("_widget", "update_user", $updateUser);	// 更新者
		if (!empty($updateDt)) $this->tmpl->addVar("_widget", "update_dt", $updateDt);	// 更新日時

		// 単位タイプ選択メニュー作成
		$this->db->getUnitType($defaultLang, array($this, 'unitTypeLoop'));

		// 通貨タイプ選択メニュー作成
		if ($this->gEnv->getMultiLanguage()){	// 多言語対応のとき
			$this->db->getCurrency($defaultLang, array($this, 'currencyLoop'));
		}
		// 課税タイプ選択メニューの作成
		$this->db->getTaxType($defaultLang, array($this, 'taxTypeLoop'));

		// 商品画像プレビューの作成
		// 画像小
		$destImg = '';
		if (empty($imageUrl_s)){
			$destImg = '<img id="preview_img_small" style="display:none;" ';
			$destImg .= 'width="' . $defaultImageSWidth . '" ';
			$destImg .= 'height="' . $defaultImageSHeight . '" ';
			$destImg .= '/>';
		} else {
			// URLマクロ変換
			$imgUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $imageUrl_s);
			$destImg = '<img id="preview_img_small" src="' . $this->getUrl($imgUrl) . '" ';
			$destImg .= 'width="' . $defaultImageSWidth . '"';
			$destImg .= ' height="' . $defaultImageSHeight . '"';
			$destImg .= ' />';
		}
		$this->tmpl->addVar("_widget", "image_s", $destImg);
		// 画像中
		$destImg = '';
		if (empty($imageUrl_m)){
			$destImg = '<img id="preview_img_medium" style="display:none;" ';
			$destImg .= 'width="' . $defaultImageMWidth . '" ';
			$destImg .= 'height="' . $defaultImageMHeight . '" ';
			$destImg .= '/>';
		} else {
			// URLマクロ変換
			$imgUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $imageUrl_m);
			$destImg = '<img id="preview_img_medium" src="' . $this->getUrl($imgUrl) . '" ';
			$destImg .= 'width="' . $defaultImageMWidth . '"';
			$destImg .= ' height="' . $defaultImageMHeight . '"';
			$destImg .= ' />';
		}
		$this->tmpl->addVar("_widget", "image_m", $destImg);
		// 画像大
		$destImg = '';
		if (empty($imageUrl_l)){
			$destImg = '<img id="preview_img_large" style="display:none;" ';
			$destImg .= 'width="' . $defaultImageLWidth . '" ';
			$destImg .= 'height="' . $defaultImageLHeight . '" ';
			$destImg .= '/>';
		} else {
			// URLマクロ変換
			$imgUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $imageUrl_l);
			$destImg = '<img id="preview_img_large" src="' . $this->getUrl($imgUrl) . '" ';
			$destImg .= 'width="' . $defaultImageLWidth . '"';
			$destImg .= ' height="' . $defaultImageLHeight . '"';
			$destImg .= ' />';
		}
		$this->tmpl->addVar("_widget", "image_l", $destImg);
		$this->tmpl->addVar("_widget", "image_s_width", $defaultImageSWidth);		// 商品画像小の幅
		$this->tmpl->addVar("_widget", "image_s_height", $defaultImageSHeight);		// 商品画像小の高さ
		$this->tmpl->addVar("_widget", "image_m_width", $defaultImageMWidth);		// 商品画像中の幅
		$this->tmpl->addVar("_widget", "image_m_height", $defaultImageMHeight);		// 商品画像中の高さ
		$this->tmpl->addVar("_widget", "image_l_width", $defaultImageLWidth);		// 商品画像大の幅
		$this->tmpl->addVar("_widget", "image_l_height", $defaultImageLHeight);		// 商品画像大の高さ
				
		// ボタンの設定
		if ($this->serialNo == 0){		// 新規追加項目を選択しているとき
			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
		} else {
			// データ更新、削除ボタン表示
			if ($this->langId == $defaultLang){		// デフォルト言語のときは「ID削除」ボタン
				$this->tmpl->setAttribute('delete_id_button', 'visibility', 'visible');// ID削除ボタン
			} else {
				$this->tmpl->setAttribute('delete_button', 'visibility', 'visible');// 削除ボタン
			}
			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');
		}
		
		// 非表示項目の設定
		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
		$this->tmpl->addVar("_widget", "product_id", $this->productId);		// 商品ID
		$this->tmpl->addVar("_widget", "image_url_s", $imageUrl_s);		// 画像小
		$this->tmpl->addVar("_widget", "image_url_m", $imageUrl_m);		// 画像中
		$this->tmpl->addVar("_widget", "image_url_l", $imageUrl_l);		// 画像大
	}
	/**
	 * 取得したデータをテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function productListLoop($index, $fetchedRow, $param)
	{
		$selected = '';
		if ($fetchedRow['pt_id'] == $this->productId){
			$selected = 'selected';
		}
		$name = $this->convertToDispString($fetchedRow['pt_code']) . '&nbsp;&nbsp;' . $this->convertToDispString($fetchedRow['pt_name']);
		
		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['pt_id']),			// 商品ID
			'name'     => $name,			// 言語名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('product_list', $row);
		$this->tmpl->parseTemplate('product_list', 'a');
		return true;
	}
	/**
	 * 取得した通貨種別をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function currencyLoop($index, $fetchedRow, $param)
	{
		$selected = '';
		if ($fetchedRow['cu_id'] == $this->currency){
			$selected = 'selected';
		}
		$name = $this->convertToDispString($fetchedRow['cu_name']);

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['cu_id']),			// 言語ID
			'name'     => $name,			// 言語名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('currency_list', $row);
		$this->tmpl->parseTemplate('currency_list', 'a');
		return true;
	}
	/**
	 * 取得した単位をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function unitTypeLoop($index, $fetchedRow, $param)
	{
		$selected = '';
		if ($fetchedRow['ut_id'] == $this->unitTypeId){
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['ut_id']),				// 単位ID
			'name'     => $this->convertToDispString($fetchedRow['ut_name']),			// 単位名
		//	'name'     => $fetchedRow['ut_name'],			// 単位名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('unit_type_list', $row);
		$this->tmpl->parseTemplate('unit_type_list', 'a');
		return true;
	}
	/**
	 * 取得した課税種別をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function taxTypeLoop($index, $fetchedRow, $param)
	{
		$selected = '';
		if ($fetchedRow['tt_id'] == $this->taxType){
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['tt_id']),				// 単位ID
			'name'     => $this->convertToDispString($fetchedRow['tt_name']),			// 単位名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('tax_type_list', $row);
		$this->tmpl->parseTemplate('tax_type_list', 'a');
		return true;
	}
	/**
	 * 取得した言語をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function langLoop($index, $fetchedRow, $param)
	{
		$selected = '';
		if ($fetchedRow['ln_id'] == $this->langId){
			$selected = 'selected';
		}
		if ($this->gEnv->getCurrentLanguage() == 'ja'){		// 日本語表示の場合
			$name = $this->convertToDispString($fetchedRow['ln_name']);
		} else {
			$name = $this->convertToDispString($fetchedRow['ln_name_en']);
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['ln_id']),			// 言語ID
			'name'     => $name,			// 言語名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('lang_list', $row);
		$this->tmpl->parseTemplate('lang_list', 'a');
		return true;
	}
	/**
	 * 価格取得
	 *
	 * @param array  	$srcRows			価格リスト
	 * @param string	$priceType			価格のタイプ
	 * @return array						取得した価格行
	 */
	function getPrice($srcRows, $priceType)
	{
		for ($i = 0; $i < count($srcRows); $i++){
			if ($srcRows[$i]['pp_price_type_id'] == $priceType){
				return $srcRows[$i];
			}
		}
		return array();
	}
	/**
	 * 画像取得
	 *
	 * @param array  	$srcRows			画像リスト
	 * @param string	$imageType			画像タイプ
	 * @return array						取得した行
	 */
	function getImage($srcRows, $sizeType)
	{
		for ($i = 0; $i < count($srcRows); $i++){
			if ($srcRows[$i]['im_size_id'] == $sizeType){
				return $srcRows[$i];
			}
		}
		return array();
	}
	/**
	 * 商品ステータス取得
	 *
	 * @param array  	$srcRows			取得行
	 * @param string	$type			商品ステータスタイプ
	 * @return array						取得した行
	 */
	function getStatus($srcRows, $type)
	{
		for ($i = 0; $i < count($srcRows); $i++){
			if ($srcRows[$i]['ps_type'] == $type){
				return $srcRows[$i];
			}
		}
		return array();
	}
	/**
	 * 商品カテゴリー取得
	 *
	 * @param array  	$srcRows			取得行
	 * @return array						取得した行
	 */
	function getCategory($srcRows)
	{
		$destArray = array();
		$itemCount = 0;
		for ($i = 0; $i < count($srcRows); $i++){
			if (!empty($srcRows[$i]['pw_category_id'])){
				$destArray[] = $srcRows[$i]['pw_category_id'];
				$itemCount++;
				if ($itemCount >= self::CATEGORY_COUNT) break;
			}
		}
		return $destArray;
	}
	/**
	 * 商品カテゴリーメニューを作成
	 *
	 * @return なし						
	 */
	function createCategoryMenu()
	{
		for ($j = 0; $j < self::CATEGORY_COUNT; $j++){
			// selectメニューの作成
			$this->tmpl->clearTemplate('category_list');
			for ($i = 0; $i < count($this->categoryListData); $i++){
				$categoryId = $this->categoryListData[$i]['pc_id'];
				$selected = '';
				if ($j < count($this->categoryArray) && $this->categoryArray[$j] == $categoryId){
					$selected = 'selected';
				}
				$menurow = array(
					'value'		=> $categoryId,			// カテゴリーID
					'name'		=> $this->categoryListData[$i]['pc_name'],			// カテゴリー名
					'selected'	=> $selected														// 選択中かどうか
				);
				$this->tmpl->addVars('category_list', $menurow);
				$this->tmpl->parseTemplate('category_list', 'a');
			}
			$itemRow = array(		
					'index'		=> $j			// 項目番号											
			);
			$this->tmpl->addVars('category', $itemRow);
			$this->tmpl->parseTemplate('category', 'a');
		}
	}
}
?>
